<?php

namespace Televox\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class graficasLlamadas extends Controller
{
    public function getRegistros(Request $request)
    {
        $results = [];
        $cuantos = 0;

        $titulo = [];
        switch (env('TIPO', 2)) {
            case 2:
            case 4:
                $datos = $request->validate([
                    'tipoLlam' => 'numeric|between:-1,1|bail|nullable',
                    'identificador' => 'numeric|bail|nullable',
                    'usuario' => 'alpha_num|bail|nullable',
                    'nombre' => 'string|bail|nullable',
                    'telefono' => 'alpha_num|bail|nullable',
                    'cuenta' => 'alpha_num|bail|nullable',
                    'segundosinicial' => 'between:0,59|numeric|bail|required_with_all:minutosinicial,horasinicial',
                    'minutosinicial' => 'between:0,59|numeric|required_with_all:segundosinicial,horasinicial',
                    'horasinicial' => 'between:0,23|numeric|bail|required_with_all:minutosinicial,segundosinicial',
                    'segundosfinal' => 'between:0,59|numeric|bail|required_with_all:minutosfinal,horasfinal',
                    'minutosfinal' => 'between:0,59|numeric|bail|required_with_all:segundosfinal,horasfinal',
                    'horasfinal' => 'between:0,23|numeric|bail|required_with_all:minutosfinal,segundosfinal',
                    'inicio' => 'before_or_equal:today|date|bail|required_with_all:fminutosinicial,fhorasinicial,fsegundosinicial',
                    'fin' => 'after_or_equal:inicio|before_or_equal:today|date|bail|required_with_all:fminutosfinal,fhorasfinal,fsegundosfinal',
                    'fminutosinicial' => 'between:0,59|numeric|bail|required_with_all:fminutosinicial,fhorasinicial,inicio',
                    'fminutosinicial' => 'between:0,59|numeric|bail|required_with_all:fsegundosinicial,fhorasinicial,inicio',
                    'fhorasinicial' => 'between:0,23|numeric|bail|required_with_all:fminutosinicial,fsegundosinicial,inicio',
                    'fsegundosfinal' => 'between:0,59|numeric|bail|required_with_all:fminutosfinal,fhorasfinal,fin',
                    'fminutosfinal' => 'between:0,59|numeric|bail|required_with_all:fsegundosfinal,fhorasfinal,fin',
                    'fhorasfinal' => 'between:0,23|numeric|bail|required_with_all:fminutosfinal,fsegundosfinal,fin',
                    'status' => 'numeric|bail|nullable',
                    'escuchando' => 'boolean|bail|nullable',
                    'archive' => 'boolean|bail|required',
                    'campaign_id' => 'nullable|bail|string|required_with:list_id,status_id',
                    'list_id' => 'nullable|bail|string',
                    'status_id' => 'nullable|bail|string',
                ]);
                $recording_log = 'recording_log';
                if (array_key_exists('archive', $datos) && $datos['archive'] != null && $datos['archive'] == true) {
                    $recording_log = 'recording_log_archive';
                }

                $filtros = [];
                if (array_key_exists('status', $datos) && $datos['status'] != null && $datos['status'] != 0) {
                    $filtros[] = ['ts.idStatus', '=', $datos['status']];
                }
                if (array_key_exists('campaign_id', $datos) && $datos['campaign_id'] != null) {
                    $filtros[] = ['vc.campaign_id', '=', $datos['campaign_id']];
                    if (array_key_exists('list_id', $datos) && $datos['list_id'] != null) {
                        $filtros[] = ['vls.list_id', '=', $datos['list_id']];
                    }
                    if (array_key_exists('status_id', $datos) && $datos['status_id'] != null) {
                        $filtros[] = ['vl.status', '=', $datos['status_id']];
                    }
                }
                $filtros[] = ['rl.filename', 'LIKE', '%_'.$request->session()->get('idClientes')];
                if (array_key_exists('cuenta', $datos) && $datos['cuenta'] != null) {
                    $filtros[] = ['vl.vendor_lead_code', 'LIKE', "%{$datos['cuenta']}%"];
                }
                if (array_key_exists('identificador', $datos) && $datos['identificador'] != null) {
                    $filtros[] = ['rl.recording_id', '=', "{$datos['identificador']}"];
                }
                if (array_key_exists('telefono', $datos) && $datos['telefono'] != null) {
                    $filtros[] = ['rl.extension', 'LIKE', "%{$datos['telefono']}%"];
                }
                if (array_key_exists('nombre', $datos) && $datos['nombre'] != null) {
                    $filtros[] = ['rl.filename', 'LIKE', "%{$datos['nombre']}%"];
                }
                if (array_key_exists('usuario', $datos) && $datos['usuario'] != null) {
                    $filtros[] = ['rl.user', 'LIKE', "%{$datos['usuario']}%"];
                }
                if (array_key_exists('segundosinicial', $datos) && $datos['segundosinicial'] != null) {
                    $filtros[] = ['rl.length_in_sec', '>=', $datos['segundosinicial'] + $datos['minutosinicial'] * 60 + $datos['horasinicial'] * 3600];
                }
                if (array_key_exists('segundosfinal', $datos) && $datos['segundosfinal'] != null) {
                    $filtros[] = ['rl.length_in_sec', '<=', $datos['segundosfinal'] + $datos['minutosfinal'] * 60 + $datos['horasfinal'] * 3600];
                }
                if (array_key_exists('tipoLlam', $datos) && $datos['tipoLlam'] != null) {
                    if ($datos['tipoLlam'] > 0) {
                        $filtros[] = ['rl.filename', 'LIKE', 'IN_%'];
                    } else {
                        if ($datos['tipoLlam'] < 0) {
                            $filtros[] = ['rl.filename', 'LIKE', 'OUT_%'];
                        }
                    }
                }

                if ((array_key_exists('campaign_id', $datos) && $datos['campaign_id'] != null) || (array_key_exists('cuenta', $datos) && $datos['cuenta'] != null)) {
                    $results = DB::connection('mysql2')->table("$recording_log as rl")->crossJoin('vicidial_list AS vl')->leftJoin('tbl_status_grab AS tsg', 'tsg.id_grab', '=', 'rl.filename')->leftJoin('tbl_status AS ts', 'tsg.id_status', '=', 'ts.idStatus')->leftJoin('audios_listen AS al', 'al.id_grab', '=', 'rl.filename')->join('vicidial_lists AS vls', 'vls.list_id', '=', 'vl.list_id')->join('vicidial_campaigns AS vc', 'vc.campaign_id', '=', 'vls.campaign_id')->whereRaw('rl.lead_id=vl.lead_id')->where($filtros)->where(function ($q) use ($datos) {
                        if (array_key_exists('inicio', $datos)) {
                            $q->where(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', date('Y-m-d', strtotime($datos['inicio'])))->whereTime('rl.start_time', '>=', date('H:i:s', strtotime("{$datos['fhorasinicial']}:{$datos['fminutosinicial']}:{$datos['fminutosinicial']}")));
                            })->orWhere(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', '>', date('Y-m-d', strtotime($datos['inicio'])));
                            });
                        }

                    })->where(function ($q) use ($datos) {
                        if (array_key_exists('fin', $datos)) {
                            $q->where(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', date('Y-m-d', strtotime($datos['fin'])))->whereTime('rl.start_time', '<=', date('H:i:s', strtotime("{$datos['fhorasfinal']}:{$datos['fminutosfinal']}:{$datos['fminutosfinal']}")));
                            })->orWhere(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', '<', date('Y-m-d', strtotime($datos['fin'])));
                            });
                        }
                    })->where(function ($q) use ($request) {
                        $q->where(function ($qq) use ($request) {
                            $qq->where('al.id_usuario', '=', $request->session()->get('id'));
                        })->orWhere(function ($qq) {
                            $qq->whereRaw('al.id_usuario IS NULL');
                        });
                    });
                    $results = $results->addSelect(DB::raw('COUNT(rl.recording_id) AS CANT'))->addSelect(DB::raw("COALESCE(ts.nombre,'Sin status') as NombreStatus"))->groupBy('NombreStatus')->get();
                } else {
                    $results = DB::connection('mysql2')->table("$recording_log as rl")->leftJoin('tbl_status_grab AS tsg', 'tsg.id_grab', '=', 'rl.filename')->leftJoin('tbl_status AS ts', 'tsg.id_status', '=', 'ts.idStatus')->leftJoin('audios_listen AS al', 'al.id_grab', '=', 'rl.filename')->where($filtros)->where(function ($q) use ($datos) {
                        if (array_key_exists('inicio', $datos)) {
                            $q->where(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', date('Y-m-d', strtotime($datos['inicio'])))->whereTime('rl.start_time', '>=', date('H:i:s', strtotime("{$datos['fhorasinicial']}:{$datos['fminutosinicial']}:{$datos['fminutosinicial']}")));
                            })->orWhere(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', '>', date('Y-m-d', strtotime($datos['inicio'])));
                            });
                        }

                    })->where(function ($q) use ($datos) {
                        if (array_key_exists('fin', $datos)) {
                            $q->where(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', date('Y-m-d', strtotime($datos['fin'])))->whereTime('rl.start_time', '<=', date('H:i:s', strtotime("{$datos['fhorasfinal']}:{$datos['fminutosfinal']}:{$datos['fminutosfinal']}")));
                            })->orWhere(function ($qq) use ($datos) {
                                $qq->whereDate('rl.start_time', '<', date('Y-m-d', strtotime($datos['fin'])));
                            });
                        }
                    })->where(function ($q) use ($request) {
                        $q->where(function ($qq) use ($request) {
                            $qq->where('al.id_usuario', '=', $request->session()->get('id'));
                        })->orWhere(function ($qq) {
                            $qq->whereRaw('al.id_usuario IS NULL');
                        });
                    });
                    $results = $results->addSelect(DB::raw('COUNT(rl.recording_id) AS CANT'))->addSelect(DB::raw("COALESCE(ts.nombre,'Sin status') as NombreStatus"))->groupBy('NombreStatus')->get();
                }

                $query = '[';
                foreach ($datos as $key => $val) {
                    $query .= "$key => $val,";
                }
                $query .= ']';
                DB::connection('mysql2')->table('tbl_log')->insertGetId(['idClientes' => $request->session()->get('idClientes'), 'ip' => $request->ip(), 'fecha' => date('Y-m-d H:i:s'), 'id_usuario' => $request->session()->get('id'), 'tipo' => 18, 'detalle' => 'El usuario '.$request->session()->get('usuario')." genero graficas con los parametros con: $query"]);
                break;
            case 1:
                $datos = $request->validate([
                    'nombre' => 'string|bail|nullable',
                    'extension' => 'numeric|bail|nullable',
                    'origen' => 'string|bail|nullable',
                    'destino' => 'numeric|bail|nullable',
                    'segundosinicial' => 'between:0,59|numeric|bail|required_with_all:minutosinicial,horasinicial',
                    'minutosinicial' => 'between:0,59|numeric|required_with_all:segundosinicial,horasinicial',
                    'horasinicial' => 'between:0,23|numeric|bail|required_with_all:minutosinicial,segundosinicial',
                    'segundosfinal' => 'between:0,59|numeric|bail|required_with_all:minutosfinal,horasfinal',
                    'minutosfinal' => 'between:0,59|numeric|bail|required_with_all:segundosfinal,horasfinal',
                    'horasfinal' => 'between:0,23|numeric|bail|required_with_all:minutosfinal,segundosfinal',
                    'inicio' => 'before_or_equal:today|date|bail|required_with_all:fminutosinicial,fhorasinicial,fsegundosinicial',
                    'fin' => 'after_or_equal:inicio|before_or_equal:today|date|bail|required_with_all:fminutosfinal,fhorasfinal,fsegundosfinal',
                    'fminutosinicial' => 'between:0,59|numeric|bail|required_with_all:fminutosinicial,fhorasinicial,inicio',
                    'fminutosinicial' => 'between:0,59|numeric|bail|required_with_all:fsegundosinicial,fhorasinicial,inicio',
                    'fhorasinicial' => 'between:0,23|numeric|bail|required_with_all:fminutosinicial,fsegundosinicial,inicio',
                    'fsegundosfinal' => 'between:0,59|numeric|bail|required_with_all:fminutosfinal,fhorasfinal,fin',
                    'fminutosfinal' => 'between:0,59|numeric|bail|required_with_all:fsegundosfinal,fhorasfinal,fin',
                    'fhorasfinal' => 'between:0,23|numeric|bail|required_with_all:fminutosfinal,fsegundosfinal,fin',
                    'status' => 'numeric|bail|nullable',
                    'escuchando' => 'boolean|bail|nullable',
                ]);
                $filtros = [];
                $filtros[] = ['cliente', '=', $request->session()->get('idClientes')];
                if (array_key_exists('status', $datos) && $datos['status'] != null) {
                    $filtros[] = ['idStatus', '=', $datos['status']];
                }
                if (array_key_exists('escuchando', $datos) && $datos['escuchando'] != null && $datos['escuchando'] == true) {
                    $filtros[] = ['listened', '=', $request->session()->get('id')];
                }

                if (array_key_exists('nombre', $datos) && $datos['nombre'] != null) {
                    $filtros[] = ['GRAB_ID', 'LIKE', "%{$datos['nombre']}%"];
                }
                if (array_key_exists('destino', $datos)) {
                    $filtros[] = ['GRAB_MACHINE', 'LIKE', "%{$datos['destino']}%"];
                }
                if (array_key_exists('origen', $datos)) {
                    $filtros[] = ['GRAB_IP', 'LIKE', "%{$datos['origen']}%"];
                }
                if (array_key_exists('extension', $datos)) {
                    $filtros[] = ['GRAB_EXT', 'LIKE', "%{$datos['extension']}%"];
                }
                if (array_key_exists('segundosinicial', $datos) && $datos['segundosinicial'] != null) {
                    $filtros[] = ['GRAB_DURATION', '>=', $datos['segundosinicial'] + $datos['minutosinicial'] * 60 + $datos['horasinicial'] * 3600];
                }
                if (array_key_exists('segundosfinal', $datos) && $datos['segundosfinal'] != null) {
                    $filtros[] = ['GRAB_DURATION', '<=', $datos['segundosfinal'] + $datos['minutosfinal'] * 60 + $datos['horasfinal'] * 3600];
                }
                $results = DB::connection('mysql')->table('grab')->where($filtros)->where(function ($q) use ($datos) {
                    if (array_key_exists('inicio', $datos)) {
                        $q->where(function ($qq) use ($datos) {
                            $qq->whereDate('GRAB_DATE', date('Y-m-d', strtotime($datos['inicio'])))->whereTime('GRAB_TIME_S', '>=', date('H:i:s', strtotime("{$datos['fhorasinicial']}:{$datos['fminutosinicial']}:{$datos['fminutosinicial']}")));
                        })->orWhere(function ($qq) use ($datos) {
                            $qq->whereDate('GRAB_DATE', '>', date('Y-m-d', strtotime($datos['inicio'])));
                        });
                    }
                })->where(function ($q) use ($datos) {
                    if (array_key_exists('fin', $datos)) {
                        $q->where(function ($qq) use ($datos) {
                            $qq->whereDate('GRAB_DATE', date('Y-m-d', strtotime($datos['fin'])))->whereTime('GRAB_TIME_S', '<=', date('H:i:s', strtotime("{$datos['fhorasfinal']}:{$datos['fminutosfinal']}:{$datos['fminutosfinal']}")));
                        })->orWhere(function ($qq) use ($datos) {
                            $qq->whereDate('GRAB_DATE', '>', date('Y-m-d', strtotime($datos['fin'])));
                        });
                    }
                });
                $results = $results->addSelect(DB::raw("CONCAT(LEFT(GRAB_TIME_E,2),':',LEFT(RIGHT(GRAB_TIME_E,4),2),':',RIGHT(GRAB_TIME_E,2)) as 'GRAB_TIME_E'"))->addSelect(DB::raw("CONCAT(LEFT(GRAB_TIME_S,2),':',LEFT(RIGHT(GRAB_TIME_S,4),2),':',RIGHT(GRAB_TIME_S,2)) as 'GRAB_TIME_S'"))->addSelect(DB::raw("CONCAT(LEFT(GRAB_DATE,4),'/',LEFT(RIGHT(GRAB_DATE,4),2),'/',RIGHT(GRAB_DATE,2)) as 'GRAB_DATE'"))->addSelect('GRAB_IP')->addSelect('GRAB_ID')->addSelect('GRAB_MACHINE')->addSelect('GRAB_EXT')->addSelect(DB::raw("TIME_FORMAT(SEC_TO_TIME(GRAB_DURATION),'%H:%i:%s') as 'GRAB_DURATION'"))->orderByRaw("CONCAT(LEFT(GRAB_DATE,4),'-',LEFT(RIGHT(GRAB_DATE,4),2),'-',RIGHT(GRAB_DATE,2),' ',CONCAT(LEFT(GRAB_TIME_S,2),':',LEFT(RIGHT(GRAB_TIME_S,4),2),'/:',RIGHT(GRAB_TIME_S,2))) DESC")->get();
                $query = '[';
                foreach ($datos as $key => $val) {
                    $query .= "$key => $val,";
                }
                $query .= ']';
                DB::connection('mysql2')->table('tbl_log')->insertGetId(['idClientes' => $request->session()->get('idClientes'), 'ip' => $request->ip(), 'fecha' => date('Y-m-d H:i:s'), 'id_usuario' => $request->session()->get('id'), 'tipo' => 18, 'detalle' => 'El usuario '.$request->session()->get('usuario')." genero graficas con los parametros con: $query"]);
                break;
            case 3:
                $datos = $request->validate([
                    'nombre' => 'string|bail|nullable',
                    'extension' => 'numeric|bail|nullable',
                    'origen' => 'string|bail|nullable',
                    'destino' => 'numeric|bail|nullable',
                    'segundosinicial' => 'between:0,59|numeric|bail|required_with_all:minutosinicial,horasinicial',
                    'minutosinicial' => 'between:0,59|numeric|required_with_all:segundosinicial,horasinicial',
                    'horasinicial' => 'between:0,23|numeric|bail|required_with_all:minutosinicial,segundosinicial',
                    'segundosfinal' => 'between:0,59|numeric|bail|required_with_all:minutosfinal,horasfinal',
                    'minutosfinal' => 'between:0,59|numeric|bail|required_with_all:segundosfinal,horasfinal',
                    'horasfinal' => 'between:0,23|numeric|bail|required_with_all:minutosfinal,segundosfinal',
                    'inicio' => 'before_or_equal:today|date|bail|required_with_all:fminutosinicial,fhorasinicial,fsegundosinicial',
                    'fin' => 'after_or_equal:inicio|before_or_equal:today|date|bail|required_with_all:fminutosfinal,fhorasfinal,fsegundosfinal',
                    'fminutosinicial' => 'between:0,59|numeric|bail|required_with_all:fminutosinicial,fhorasinicial,inicio',
                    'fminutosinicial' => 'between:0,59|numeric|bail|required_with_all:fsegundosinicial,fhorasinicial,inicio',
                    'fhorasinicial' => 'between:0,23|numeric|bail|required_with_all:fminutosinicial,fsegundosinicial,inicio',
                    'fsegundosfinal' => 'between:0,59|numeric|bail|required_with_all:fminutosfinal,fhorasfinal,fin',
                    'fminutosfinal' => 'between:0,59|numeric|bail|required_with_all:fsegundosfinal,fhorasfinal,fin',
                    'fhorasfinal' => 'between:0,23|numeric|bail|required_with_all:fminutosfinal,fsegundosfinal,fin',
                    'status' => 'numeric|bail|nullable',
                    'escuchando' => 'boolean|bail|nullable',
                ]);
                $filtros = [];
                $filtros[] = ['cliente', '=', $request->session()->get('idClientes')];

                if (array_key_exists('status', $datos) && $datos['status'] != null) {
                    $filtros[] = ['idStatus', '=', $datos['status']];
                }
                if (array_key_exists('escuchando', $datos) && $datos['escuchando'] != null && $datos['escuchando'] == true) {
                    $filtros[] = ['listened', '=', $request->session()->get('id')];
                }
                if (array_key_exists('nombre', $datos) && $datos['nombre'] != null) {
                    $filtros[] = ['idGrabacion', 'LIKE', "%{$datos['nombre']}%"];
                }
                if (array_key_exists('origen', $datos)) {
                    $filtros[] = ['ANI', 'LIKE', "%{$datos['origen']}%"];
                }
                if (array_key_exists('extension', $datos)) {
                    $filtros[] = ['extension', 'LIKE', "%{$datos['extension']}%"];
                }
                if (array_key_exists('segundosinicial', $datos) && $datos['segundosinicial'] != null) {
                    $filtros[] = ['duracion', '>=', $datos['segundosinicial'] + $datos['minutosinicial'] * 60 + $datos['horasinicial'] * 3600];
                }
                if (array_key_exists('segundosfinal', $datos) && $datos['segundosfinal'] != null) {
                    $filtros[] = ['duracion', '<=', $datos['segundosfinal'] + $datos['minutosfinal'] * 60 + $datos['horasfinal'] * 3600];
                }

                $results = DB::connection('mysql')->table('aurolog_grabaciones')->where($filtros)->where(function ($q) use ($datos) {
                    if (array_key_exists('inicio', $datos)) {
                        $q->where(function ($qq) use ($datos) {
                            $qq->whereRaw("DATE_ADD('1900-01-01',INTERVAL dia-2 DAY)=?", [date('Y-m-d', strtotime($datos['fin']))])->whereRaw('sec_to_time(hora)>=?', [date('H:i:s', strtotime("{$datos['fhorasfinal']}:{$datos['fminutosfinal']}:{$datos['fminutosfinal']}"))]);
                        })->orWhere(function ($qq) use ($datos) {
                            $qq->whereRaw("DATE_ADD('1900-01-01',INTERVAL dia-2 DAY)<", [date('Y-m-d', strtotime($datos['fin']))]);
                        });
                    }
                })->where(function ($q) use ($datos) {
                    if (array_key_exists('destino', $datos)) {
                        $q->whereRaw("CONCAT(DNIS,' ',digitos) LIKE '?%'", [$datos['destino']]);
                    }
                })->where(function ($q) use ($datos) {

                    if (array_key_exists('fin', $datos)) {
                        $q->where(function ($qq) use ($datos) {
                            $qq->whereRaw("DATE_ADD('1900-01-01',INTERVAL dia-2 DAY)=?", [date('Y-m-d', strtotime($datos['fin']))])->whereRaw('sec_to_time(hora)<=?', [date('H:i:s', strtotime("{$datos['fhorasfinal']}:{$datos['fminutosfinal']}:{$datos['fminutosfinal']}"))]);
                        })->orWhere(function ($qq) use ($datos) {
                            $qq->whereRaw("DATE_ADD('1900-01-01',INTERVAL dia-2 DAY)>", [date('Y-m-d', strtotime($datos['fin']))]);
                        });
                    }

                });
                $results = $results->addSelect('idGrabacion')->addSelect('ANI')->addSelect(BD::raw("CONCAT(DNIS,' ',digitos) as 'Destino'"))->addSelect(DB::raw("sec_to_time(hora) as 'horai'"))->addSelect(DB::raw("sec_to_time(hora+duracion) as 'horaf'"))->addSelect(DB::raw("sec_to_time(duracion) as 'duracion'"))->addSelect('extension')->addSelect(DB::raw("DATE_ADD('1900-01-01',INTERVAL dia-2 DAY) as 'fecha'"))->addSelect(DB::raw("LEFT(substr(archivoVoz,Locate('/',archivoVoz,Locate('/',archivoVoz,Locate('/',archivoVoz,Locate('/2',archivoVoz)+1)+1)+1)+1),LENGTH(substr(archivoVoz,Locate('/',archivoVoz,Locate('/',archivoVoz,Locate('/',archivoVoz,Locate('/2',archivoVoz)+1)+1)+1)+1))-4) as 'GRAB_ID'"))->orderByRaw('idunico DESC')->get();
                $query = '[';
                foreach ($datos as $key => $val) {
                    $query .= "$key => $val,";
                }
                $query .= ']';
                DB::connection('mysql2')->table('tbl_log')->insertGetId(['idClientes' => $request->session()->get('idClientes'), 'ip' => $request->ip(), 'fecha' => date('Y-m-d H:i:s'), 'id_usuario' => $request->session()->get('id'), 'tipo' => 18, 'detalle' => 'El usuario '.$request->session()->get('usuario')." genero graficas con los parametros con: $query"]);
                break;
        }

        return ['Estado' => 'ok', 'Registros' => $results];
    }
}
